# biocircuits

Utilities to accompany *Biological Circuit Design* by Michael Elowitz and Justin Bois.


## Installation

To install use pip:

    pip install biocircuits


## Documentation

You can access the docs from the [Biological Circuit Design website](https://biocircuits.github.io/package_docs/index.html).